# Program to generate a plot for a function using matplotlib and numpy.
# This program generates a plot for the probability density for an one-dimensional finite square-well potential
#
# Dr. Walter F. de Azevedo Jr.
# https://azevedolab.net/
# Porto Alegre, April 17, 2019

# Import libraries
import matplotlib.pyplot as plt
import numpy as np

# Define parameters
h = 6.626070040e-34     # Planck constant in J.s (source: https://physics.nist.gov/cgi-bin/cuu/Value?h)
h_bar = h/(2*np.pi)     # h bar in J.s
m = 9.10938356e-31      # Mass of electron in Kg (source: https://physics.nist.gov/cgi-bin/cuu/Value?me|search_for=electron+mass)
E = 3.204354e-19        # Energy in Joules (2 eV)
V0 = 9.613062e-19       # Energy in Joules (6 eV)
A = 1                   # Set Amplitude to 1
a = 5e-9                # Length of the well (m)

# Calculate k1 and k2
k1 = (np.sqrt(2*m*E))/h_bar
k2 = (np.sqrt(2*m*(V0-E)))/h_bar

# Define limits in nanometers ( 1 nm = 10**-9 m)
x_min = -a
x_0 = -a/2
x_1 = a/2
x_max = a

# Define x range with linspace
x_I = np.linspace(x_min,x_0,500)
x_II = np.linspace(x_0,x_1,500)
x_III = np.linspace(x_1,x_max,500)

# Define eigenfunction psi (x<-a/2)
psi_I = -A*(np.sin(k1*a/2))*(np.exp(k2*a/2))*(np.exp(k2*x_I))
psi_II = A*np.sin(k1*x_II)
psi_III = A*np.sin(k1*a/2)*np.exp(k2*a/2)*np.exp(-k2*x_III)
prob_dens_I = psi_I*psi_I
prob_dens_II = psi_II*psi_II
prob_dens_III = psi_III*psi_III

# Set up x-axis limits
plt.xlim(x_min,x_max)

# Set up y-axis limits
plt.ylim(-1.6,1.6)

# Set up grid
plt.grid(True)

# Add labels
plt.xlabel('x ($10^{-9}$m)',fontsize=14)                                    # Add axis label
plt.ylabel('$\psi^*\psi$',fontsize=24)                                      # Add axis label
plt.title('Probability density for a finite square-well potential (E<Vo)')  # Add title

# Create plot
plt.plot(x_I,prob_dens_I)
plt.plot(x_II,prob_dens_II)
plt.plot(x_III,prob_dens_III)

# Show plot
plt.show()

# Save plot on png file
plt.savefig("square_potential_prob_density_I_II_III.png")