# Program to generate a plot for a function using matplotlib and numpy
# This program generates a plot for the probability density for an one-dimensional step potential with E<Vo
#
# Dr. Walter F. de Azevedo Jr.
# https://azevedolab.net/
# Porto Alegre, April 17, 2019

# Import libraries
import matplotlib.pyplot as plt
import numpy as np

# Define parameters
h = 6.626070040e-34     # Planck constant in J.s (source: https://physics.nist.gov/cgi-bin/cuu/Value?h)
h_bar = h/(2*np.pi)     # h bar in J.s
m = 9.10938356e-31      # Mass of electron in Kg (source: https://physics.nist.gov/cgi-bin/cuu/Value?me|search_for=electron+mass)
E = 3.204354e-19        # Energy in Joules (2 eV)
V0 = 9.613062e-19       # Energy in Joules (6 eV)
D = 1                   # Set Amplitude to 1

# Calculate k1 and k2
k1 = (np.sqrt(2*m*E))/h_bar
k2 = (np.sqrt(2*m*(V0-E)))/h_bar

# Define limits in nanometers ( 1 nm = 10**-9 m)
x_min = -5e-9
x_0 = 0.0
x_max = 1e-9

# Define x range with linspace
x1 = np.linspace(x_min,x_0,500)
x2 = np.linspace(x_0,x_max,500)

# Define eigenfunctions psi_I and psi_I (solution of Schroedinger equation for a step potential (E<Vo))
psi_I = D*np.cos(k1*x1) - D*(k2/k1)*np.sin(k1*x1)
psi_II = D*np.exp(-k2*x2)
prob_dens1 = psi_I*psi_I
prob_dens2 = psi_II*psi_II

# Set up x-axis limits
plt.xlim(x_min,x_max)

# Set up y-axis limits
plt.ylim(-4.0,4.0)

# Set up grid
plt.grid(True)

# Add labels
plt.xlabel('x ($10^{-9}$m)',fontsize=14)                                    # Add axis label
plt.ylabel('$\psi^*\psi$',fontsize=24)                                      # Add axis label
plt.title('Probability density for a step potential (E<Vo)')                # Add title

# Create plot
plt.plot(x1,prob_dens1)
plt.plot(x2,prob_dens2)

# Show plot
plt.show()

# Save plot on png file
plt.savefig("step_potential_prob_density_I_II.png")